@@ -84,7 +84,7 @@ def done(ctx, grades):
     "--avg-progress-only",
     "-o",
     is_flag=True,
-    help="Print the program version and exit.",
+    help="Show the average for modules in progress only.",
 )
 @pass_grades
 @run_if_config_exists
@@ -124,3 +124,99 @@ def check():
 def score_accuracy(ctx, grades):
     """Check for rounding errors when averaging module score."""
     commands.check_score_accuracy(grades)
+
+
+@cli.group()
+def plot():
+    """Plot progress made over time."""
+
+
+@plot.command()
+@click.option(
+    "-d",
+    "--dpi",
+    default=300,
+    show_default=True,
+    type=click.IntRange(100, 1000),
+    help="Specify the output quality in dots per inch.",
+)
+@click.option(
+    "--filename",
+    type=str,
+    help="Change the output file name.",
+)
+@click.option(
+    "--long-module-names",
+    is_flag=True,
+    default=False,
+    help="Display the full name of each module.",
+)
+@click.option(
+    "--no-avg-overall",
+    is_flag=True,
+    default=False,
+    help="Remove the weighted average obtained across the degree.",
+)
+@click.option(
+    "--no-avg-unweighted",
+    is_flag=True,
+    default=False,
+    help="Remove the unweighted average per semester.",
+)
+@click.option(
+    "--no-avg-weighted",
+    is_flag=True,
+    default=False,
+    help="Remove the weighted average per semester.",
+)
+@click.option(
+    "--no-avgs",
+    is_flag=True,
+    default=False,
+    help="Remove all unweighted and weighted average lines.",
+)
+@click.option(
+    "--no-grades",
+    is_flag=True,
+    default=False,
+    help="Do not display the grade for any module.",
+)
+@click.option(
+    "--no-module-names",
+    is_flag=True,
+    default=False,
+    help="Remove the display of module names entirely.",
+)
+@click.option(
+    "--no-trend",
+    is_flag=True,
+    default=False,
+    help="Remove the trend line.",
+)
+@click.option(
+    "--path",
+    type=str,
+    help="Set the output path to save the generated plot.",
+)
+@click.option(
+    "--title",
+    type=str,
+    help="Print a custom title for the graph.",
+)
+@click.option(
+    "--title-keep-date",
+    is_flag=True,
+    default=False,
+    help="Append today's date to the title when used with `--title`.",
+)
+@click.option(
+    "--title-no-date",
+    is_flag=True,
+    default=False,
+    help="Remove the part `as of YYYY-MM-DD` in the title of the graph.",
+)
+@pass_grades
+@run_if_config_exists
+def modules(ctx, grades, **kwargs):
+    """Produce a scatter plot showing all individual grades."""
+    commands.plot_modules(grades=grades, options=kwargs)
