@@ -6,7 +6,6 @@ List the commands available from the CLI: one per function.
 from datetime import datetime
 from pathlib import Path
 import os
-import sys
 
 # Third-party library imports
 import click
@@ -52,33 +51,31 @@ def check_score_accuracy(grades) -> dict:
     return expected_dict
 
 
-def generate_sample(config) -> bool:
+def generate_sample(config) -> dict:
     """Generate a sample grades YAML config file."""
     if os.path.exists(config.path):
-        click.secho(
-            f"Will not overwrite existing {config.path}", fg="bright_yellow"
-        )
-        return False
+        err_msg = f"Will not overwrite existing {config.path}"
+        click.secho(err_msg, fg="bright_yellow")
+        return {"ok": False, "error": err_msg}
 
-    commands_helpers.generate_sample_copy_config_file_and_print_message(
+    return commands_helpers.generate_sample_copy_config_file_and_print_message(
         config_path=config.path
     )
-    return True
 
 
-def generate_sample_overwrite(config) -> None:
+def generate_sample_overwrite(config) -> dict:
     """Generate a sample grades YAML config file: overwrite if it exists."""
     if os.path.exists(config.path):
         click.secho(f"Overwriting {config.path}", fg="bright_blue")
     else:
         click.secho(f"Creating {config.path}", fg="bright_blue")
 
-    commands_helpers.generate_sample_copy_config_file_and_print_message(
+    return commands_helpers.generate_sample_copy_config_file_and_print_message(
         config_path=config.path
     )
 
 
-def plot_modules(grades: Grades, options: dict) -> None:
+def plot_modules(grades: Grades, options: dict = {}) -> dict:
     """
     Plot modules over time with additional information and save the generated
     plot to `path`. It might be a good idea to refactor this gigantic function
@@ -96,11 +93,9 @@ def plot_modules(grades: Grades, options: dict) -> None:
         )
         df = commands_helpers.get_modules_done_dataframe(grades, modules)
     else:
-        click.secho(
-            "Aborting: there is not enough data to produce a plot.",
-            fg="bright_blue",
-        )
-        sys.exit()
+        err_msg = "Aborting: there is not enough data to produce a plot."
+        click.secho(err_msg, fg="bright_blue")
+        return {"ok": False, "error": err_msg}
 
     # Drop unneeded columns
     df = df.drop(["ECTS", "US"], axis=1)
@@ -129,7 +124,7 @@ def plot_modules(grades: Grades, options: dict) -> None:
     )
 
     # Figure aspect ratio and output quality in dots per inch
-    plt.figure(figsize=(12, 6), dpi=options["dpi"])
+    plt.figure(figsize=(12, 6), dpi=options.get("dpi", 100))
 
     # Graph title: if the `title` option is passed, set the title to that and
     # optionally append today's date if the `keep_date_in_title` option is set.
@@ -219,7 +214,7 @@ def plot_modules(grades: Grades, options: dict) -> None:
     # It's not much of a line with less than 2 different dates...
     if len(dates) < 2:
         click.secho(
-            f"Not enough data to plot a line: skipping trend and averages...",
+            "Not enough data to plot a line: skipping trend and averages...",
             fg="bright_yellow",
         )
     else:
@@ -364,17 +359,20 @@ def plot_modules(grades: Grades, options: dict) -> None:
 
     if options.get("path"):
         if not os.path.exists(options.get("path", "")):
+            err_msg = (
+                "Cannot save to the path specified: "
+                f"{Path(options.get('path', '')) / filename}"
+            )
             click.secho(
-                f"Cannot save to the path specified: {Path(options.get('path', '')) / filename}",
+                err_msg,
                 fg="bright_red",
             )
             click.secho(
                 "Make sure the output directory exists.",
                 fg="blue",
             )
-            sys.exit()
-        else:
-            filepath = Path(options.get("path", "")) / filename
+            return {"ok": False, "error": err_msg}
+        filepath = Path(options.get("path", "")) / filename
 
     if os.path.exists(filepath):
         click.secho(
@@ -392,37 +390,39 @@ def plot_modules(grades: Grades, options: dict) -> None:
                 "Aborting: the existing file was kept intact.",
                 fg="bright_blue",
             )
-            sys.exit()
+            return {"ok": True, "save_filepath": filepath}
 
     try:
         plt.savefig(filepath)
         click.secho(f"Plot saved to {filepath}", fg="bright_green")
+        return {"ok": True, "save_filepath": filepath}
     except PermissionError:
-        click.secho(
-            f"PermissionError: could not save the output to {filepath}",
-            fg="bright_red",
-        )
+        err_msg = f"PermissionError: could not save the output to {filepath}"
+        click.secho(err_msg, fg="bright_red")
+        return {"ok": False, "error": err_msg}
 
 
-def summarize_all(grades: Grades, symbol: str = "=", repeat: int = 80) -> None:
+def summarize_all(grades: Grades, symbol: str = "=", repeat: int = 80) -> dict:
     """Print a summary of modules done and in progress."""
     click.secho("Modules completed", fg="bright_cyan")
     click.secho(symbol * repeat, fg="bright_cyan")
-    summarize_done(grades)
+    summary_done = summarize_done(grades)
 
     click.secho("\nModules in progress", fg="bright_cyan")
     click.secho(symbol * repeat, fg="bright_cyan")
-    summarize_progress(grades)
+    summary_progress = summarize_progress(grades)
+
+    return {"done": summary_done, "progress": summary_progress}
 
 
-def summarize_done(grades):
+def summarize_done(grades) -> dict:
     """Print a summary of the progress made so far for modules that are done
     and dusted."""
     if not (finished_modules := grades.get_list_of_finished_modules()):
         click.secho(
             "No modules done. Good luck in your journey!", fg="bright_blue"
         )
-        return
+        return {}
     modules = grades_helpers.get_grades_list_as_list_of_dicts(finished_modules)
 
     df = commands_helpers.get_modules_done_dataframe(grades, modules)
@@ -464,15 +464,31 @@ def summarize_done(grades):
         fg="cyan",
     )
 
+    return {
+        "modules": modules,
+        "weighted_average": wavg,
+        "unweighted_average": uavg,
+        "weighted_ects": wects,
+        "unweighted_ects": uects,
+        "weighted_us": wus,
+        "unweighted_us": uus,
+        "weighted_class": wclass,
+        "weighted_gpa_us": wgpa_us,
+        "weighted_gpa_uk": wgpa_uk,
+        "credits_done": total_credits,
+        "percentage_done": pct_done,
+    }
 
-def summarize_progress(grades):
+
+def summarize_progress(grades) -> dict:
     """Print a summary of only the modules that are currently in progress."""
     if commands_helpers.there_are_no_modules_in_progress(grades):
-        return
+        return {}
 
-    df_all_scores, _ = commands_helpers.get_modules_in_progress_dataframe(
-        grades
-    )
+    (
+        df_all_scores,
+        in_progress,
+    ) = commands_helpers.get_modules_in_progress_dataframe(grades)
     commands_helpers.pprint_dataframe(df_all_scores)
 
     wavg = grades.weighted_average_in_progress
@@ -480,10 +496,16 @@ def summarize_progress(grades):
     commands_helpers.print_weighted_average_in_progress(wavg)
     commands_helpers.print_unweighted_average_in_progress(uavg)
 
+    return {
+        "modules": in_progress,
+        "weighted_average": wavg,
+        "unweighted_average": uavg,
+    }
 
-def summarize_progress_avg_progress_only(grades):
+
+def summarize_progress_avg_progress_only(grades) -> dict:
     if commands_helpers.there_are_no_modules_in_progress(grades):
-        return
+        return {}
 
     (
         df_all_scores,
@@ -503,3 +525,9 @@ def summarize_progress_avg_progress_only(grades):
         commands_helpers.print_unweighted_average_in_progress(
             uavg, only_in_progress=True
         )
+
+    return {
+        "modules": in_progress,
+        "weighted_average": wavg,
+        "unweighted_average": uavg,
+    }
